#
# spec file for package kuberlr
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kuberlr
Version:        0.4.1
Release:        1.7
Summary:        A tool that simplifies the management of multiple versions of kubectl
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/flavio/kuberlr
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.16
Requires(post): %fillup_prereq
Requires(post): update-alternatives
Requires(postun):update-alternatives
%if 0%{?suse_version} <= 1500
Conflicts:      kubernetes-client
%endif
Provides:       kubernetes-client-provider = %{version}

%description
kuberlr (kube-ruler) is a simple wrapper for kubectl. Its main purpose is to
make it easy to manage clusters running different versions of kubernetes.

%prep
%setup -q -a1
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X=github.com/flavio/kuberlr/pkg/kuberlr.Version=%{version}" \
   -o %{name} ./cmd/%{name}

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
%if 0%{?suse_version} <= 1500
install -D -m 0644 %{name}.conf.example %{buildroot}/%{_sysconfdir}/%{name}.conf
%else
install -D -m 0644 %{name}.conf.example %{buildroot}/%{_distconfdir}/%{name}.conf
%endif
# update alternatives
ln -s %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%post
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kuberlr 1000

%postun
if [ ! -f %{_bindir}/%{name} ] ; then
  update-alternatives --remove kubectl %{_bindir}/%{name}
fi

%files
%license LICENSE
%doc README.md
%{_bindir}/kubectl
%{_bindir}/%{name}
%ghost %{_sysconfdir}/alternatives/kubectl
%if 0%{?suse_version} <= 1500
%config %{_sysconfdir}/%{name}.conf
%else
%{_distconfdir}/%{name}.conf
%endif

%changelog
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 0.4.1:
  * Tag release 0.4.1
  * Fixing issue of process holding on to file during rename
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 0.4.0:
  * Release version 0.4.0
  * Fix error reporting inside of downloader
  * Add `get` command
  * Update github.com/blang/semver dependency
  * Don't parse kubectl commandline with flag.Parse()
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 0.3.2:
  * Tag version v0.3.2
  * Act on linter directives
  * Copy the temp file to dest only if rename fails
  * style improvements - no functional change
  * download the hash before the document
  * ioutil.TempFile returns an open file object
  * Convert the sha mismatch error msg into a custom error
  * When downloading versions of kubectl, verify their contents against known SHA256 hashes
  * Remove vendored tree
  * Allow to override build date with SOURCE_DATE_EPOCH
* Fri Jan  7 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go 1.16 or higher
- major overhaul of the package to adhere to common go build commands
  - use 'buildmode=pie'
  - strip binary
  - do not use the Makefile, instead directly run the few commands
* Fri Sep 11 2020 dmueller@suse.com
- Update to version 0.3.1:
  * Prepare for release of v0.3.1
  * fix: set progress bar desc to shorter string
  * Update Changelog
  * Update README to mention all the platforms supported
  * GitHub actions: enable test matrix
  * Build kuberlr binary for windows
  * windows: fix path construction for download dir
  * windows: require .exe extension on windows
  * windows: add filename extension utils
* Tue Jul 14 2020 Dirk Mueller <dmueller@suse.com>
- fix update-alternatives logic
- set highest priority
* Mon Jul 13 2020 Dirk Mueller <dmueller@suse.com>
- spec file cleanups
- use vendor.tar.gz
* Fri Jul 10 2020 Flavio Castelli <fcastelli@suse.com>
- Update to version 0.3.0
- Ensure OIDC authentication works
* Mon Jul  6 2020 Flavio Castelli <fcastelli@suse.com>
- Ensure the right version of Go is used, this fixes builds on
  tumbleweed
* Mon Jul  6 2020 Flavio Castelli <fcastelli@suse.com>
- Update to version version 0.2.1
